@@ -16,7 +16,7 @@
 # specific language governing permissions and limitations
 # under the License.
 import time
-from typing import Any, Optional
+from typing import Any, Optional, Union
 
 from airflow.exceptions import AirflowException
 from airflow.providers.http.hooks.http import HttpHook
@@ -28,9 +28,7 @@ class AirbyteHook(HttpHook):
 
     :param airbyte_conn_id: Required. The name of the Airflow connection to get
         connection information for Airbyte.
-    :type airbyte_conn_id: str
     :param api_version: Optional. Airbyte API version.
-    :type api_version: str
     """
 
     conn_name_attr = 'airbyte_conn_id'
@@ -46,23 +44,20 @@ class AirbyteHook(HttpHook):
     ERROR = "error"
     INCOMPLETE = "incomplete"
 
-    def __init__(self, airbyte_conn_id: str = "airbyte_default", api_version: Optional[str] = "v1") -> None:
+    def __init__(self, airbyte_conn_id: str = "airbyte_default", api_version: str = "v1") -> None:
         super().__init__(http_conn_id=airbyte_conn_id)
         self.api_version: str = api_version
 
     def wait_for_job(
-        self, job_id: str, wait_seconds: Optional[float] = 3, timeout: Optional[float] = 3600
+        self, job_id: Union[str, int], wait_seconds: float = 3, timeout: Optional[float] = 3600
     ) -> None:
         """
         Helper method which polls a job to check if it finishes.
 
         :param job_id: Required. Id of the Airbyte job
-        :type job_id: str
         :param wait_seconds: Optional. Number of seconds between checks.
-        :type wait_seconds: float
         :param timeout: Optional. How many seconds wait for job to be ready.
             Used only if ``asynchronous`` is False.
-        :type timeout: float
         """
         state = None
         start = time.monotonic()
@@ -71,7 +66,7 @@ class AirbyteHook(HttpHook):
                 raise AirflowException(f"Timeout: Airbyte job {job_id} is not ready after {timeout}s")
             time.sleep(wait_seconds)
             try:
-                job = self.get_job(job_id=job_id)
+                job = self.get_job(job_id=(int(job_id)))
                 state = job.json()["job"]["status"]
             except AirflowException as err:
                 self.log.info("Retrying. Airbyte API returned server error when waiting for job: %s", err)
@@ -93,7 +88,6 @@ class AirbyteHook(HttpHook):
         Submits a job to a Airbyte server.
 
         :param connection_id: Required. The ConnectionId of the Airbyte Connection.
-        :type connection_id: str
         """
         return self.run(
             endpoint=f"api/{self.api_version}/connections/sync",
@@ -106,7 +100,6 @@ class AirbyteHook(HttpHook):
         Gets the resource representation for a job in Airbyte.
 
         :param job_id: Required. Id of the Airbyte job
-        :type job_id: int
         """
         return self.run(
             endpoint=f"api/{self.api_version}/jobs/get",
@@ -114,6 +107,18 @@ class AirbyteHook(HttpHook):
             headers={"accept": "application/json"},
         )
 
+    def cancel_job(self, job_id: int) -> Any:
+        """
+        Cancel the job when task is cancelled
+
+        :param job_id: Required. Id of the Airbyte job
+        """
+        return self.run(
+            endpoint=f"api/{self.api_version}/jobs/cancel",
+            json={"id": job_id},
+            headers={"accept": "application/json"},
+        )
+
     def test_connection(self):
         """Tests the Airbyte connection by hitting the health API"""
         self.method = 'GET'
